@@ -735,7 +735,7 @@ xls_header_footer_export1 (GString *res, const char *s, const char *section)
 
 
 char *
-xls_header_footer_export (const PrintHF *hf)
+xls_header_footer_export (const GnmPrintHF *hf)
 {
 	GString *res = g_string_new (NULL);
 
@@ -747,7 +747,7 @@ xls_header_footer_export (const PrintHF *hf)
 }
 
 void
-xls_header_footer_import (PrintHF *hf, const char *txt)
+xls_header_footer_import (GnmPrintHF *hf, const char *txt)
 {
 	char section = 'L';
 	GString *accum;
@@ -821,3 +821,88 @@ xls_header_footer_import (PrintHF *hf, const char *txt)
 		txt++;
 	}
 }
+
+/*****************************************************************************/
+
+void
+xls_arrow_to_xl (GOArrow const *arrow, double width,
+		 XLArrowType *ptyp, int *pl, int *pw)
+{
+	double s = CLAMP (width, 1.0, 5); /* Excel arrows scale with line width */
+
+	switch (arrow->typ) {
+	case GO_ARROW_NONE:
+		*ptyp = XL_ARROW_NONE;
+		*pl = 0;
+		*pw = 0;
+		break;
+	case GO_ARROW_KITE:
+		if (fabs (arrow->a - arrow->b) < 0.01) {
+			*ptyp = XL_ARROW_REGULAR;
+			*pl = (int)CLAMP ((arrow->a / (s * 3.5)) - 1, 0.0, 2.0);
+			*pw = (int)CLAMP ((arrow->c / (s * 2.5)) - 1, 0.0, 2.0);
+		} else if (arrow->a > arrow->b) {
+			*ptyp = XL_ARROW_DIAMOND;
+			*pl = (int)CLAMP ((arrow->a / (s * 5.0)) - 1, 0.0, 2.0);
+			*pw = (int)CLAMP ((arrow->c / (s * 2.5)) - 1, 0.0, 2.0);
+		} else if (arrow->a < 0.5 * arrow->b) {
+			*ptyp = XL_ARROW_OPEN;
+			*pl = (int)CLAMP ((arrow->a / (s * 1.0)) - 1, 0.0, 2.0);
+			*pw = (int)CLAMP ((arrow->c / (s * 1.5)) - 1, 0.0, 2.0);
+		} else {
+			*ptyp = XL_ARROW_STEALTH;
+			*pl = (int)CLAMP ((arrow->b / (s * 4.0)) - 1, 0.0, 2.0);
+			*pw = (int)CLAMP ((arrow->c / (s * 2.0)) - 1, 0.0, 2.0);
+		}
+		break;
+	case GO_ARROW_OVAL:
+		*ptyp = XL_ARROW_OVAL;
+		*pl = (int)CLAMP ((arrow->a / (s * 2.5)) - 1, 0.0, 2.0);
+		*pw = (int)CLAMP ((arrow->b / (s * 2.5)) - 1, 0.0, 2.0);
+		break;
+	default:
+		g_assert_not_reached ();
+	}
+}
+
+void
+xls_arrow_from_xl (GOArrow *arrow, double width, XLArrowType typ, int l, int w)
+{
+	double s = CLAMP (width, 1.0, 5); /* Excel arrows scale with line width */
+
+	switch (typ) {
+	case XL_ARROW_NONE:
+		go_arrow_clear (arrow);
+		break;
+	default:
+	case XL_ARROW_REGULAR:
+		go_arrow_init_kite (arrow,
+				    s * 3.5 * (l + 1),
+				    s * 3.5 * (l + 1),
+				    s * 2.5 * (w + 1));
+		break;
+	case XL_ARROW_STEALTH:
+		go_arrow_init_kite (arrow,
+				    s * 2.5 * (l + 1),
+				    s * 4.0 * (l + 1),
+				    s * 2.0 * (w + 1));
+		break;
+	case XL_ARROW_DIAMOND:
+		go_arrow_init_kite (arrow,
+				    s * 5 * (l + 1),
+				    s * 2.5 * (l + 1),
+				    s * 2.5 * (w + 1));
+		break;
+	case XL_ARROW_OVAL:
+		go_arrow_init_oval (arrow, s * 2.5 * (l + 1), s * 2.5 * (w + 1));
+		break;
+	case XL_ARROW_OPEN: /* Approximation! */
+		go_arrow_init_kite (arrow,
+				    s * 1.0 * (l + 1),
+				    s * 2.5 * (l + 1),
+				    s * 1.5 * (w + 1));
+		break;
+	}
+}
+
+/*****************************************************************************/
