@@ -102,10 +102,25 @@ unsigned xls_paper_size (GtkPaperSize *ps, gboolean rotated);
 
 /*****************************************************************************/
 
-char *xls_header_footer_export (const PrintHF *hf);
-void xls_header_footer_import (PrintHF *hf, const char *txt);
+char *xls_header_footer_export (const GnmPrintHF *hf);
+void xls_header_footer_import (GnmPrintHF *hf, const char *txt);
 
 /*****************************************************************************/
 
+typedef enum {
+	XL_ARROW_NONE = 0,
+	XL_ARROW_REGULAR = 1,
+	XL_ARROW_STEALTH = 2,
+	XL_ARROW_DIAMOND = 3,
+	XL_ARROW_OVAL = 4,
+	XL_ARROW_OPEN = 5
+} XLArrowType;
+
+void xls_arrow_to_xl (GOArrow const *arrow, double width,
+		      XLArrowType *ptyp, int *pl, int *pw);
+void xls_arrow_from_xl (GOArrow *arrow, double width,
+			XLArrowType typ, int l, int w);
+
+/*****************************************************************************/
 
 #endif /* GNM_MS_EXCEL_UTIL_H */
