@@ -444,7 +444,7 @@ check_for_changed_options (SolverState *state)
 				     state->orig_params)) {
 		GOUndo *undo = set_params (sheet, state->orig_params);
 		GOUndo *redo = set_params (sheet, sheet->solver_parameters);
-		cmd_generic (WORKBOOK_CONTROL (state->wbcg),
+		cmd_generic (GNM_WBC (state->wbcg),
 			     _("Changing solver parameters"),
 			     undo, redo);
 
@@ -763,7 +763,7 @@ run_solver (SolverState *state, GnmSolverParameters *param)
 	/* ---------------------------------------- */
 
 	ok = gnm_solver_start (sol,
-			       WORKBOOK_CONTROL (state->wbcg),
+			       GNM_WBC (state->wbcg),
 			       &err);
 	if (ok) {
 		dialog_res = go_gtk_dialog_run (dialog, top);
@@ -836,7 +836,7 @@ run_solver (SolverState *state, GnmSolverParameters *param)
 			redo = go_undo_combine (redo, redo_report);
 		}
 
-		cmd_generic (WORKBOOK_CONTROL (state->wbcg),
+		cmd_generic (GNM_WBC (state->wbcg),
 			     _("Running solver"),
 			     undo, redo);
 		res = g_object_ref (sol->result);
@@ -865,7 +865,7 @@ solver_add_scenario (SolverState *state, GnmSolverResult *res, gchar const *name
 	GnmValue const *vinput;
 	GnmScenario *sc;
 	GnmSheetRange sr;
-	WorkbookControl *wbc = WORKBOOK_CONTROL (state->wbcg);
+	WorkbookControl *wbc = GNM_WBC (state->wbcg);
 
 	vinput = gnm_solver_param_get_input (param);
 	gnm_sheet_range_from_value (&sr, vinput);
@@ -991,7 +991,7 @@ dialog_init (SolverState *state)
 	g_signal_connect (G_OBJECT (state->close_button), "clicked",
 			  G_CALLBACK (cb_dialog_close_clicked), state);
 
-	gnumeric_init_help_button (go_gtk_builder_get_widget (state->gui,
+	gnm_init_help_button (go_gtk_builder_get_widget (state->gui,
 							 "helpbutton"),
 				   GNUMERIC_HELP_LINK_SOLVER);
 
@@ -1021,7 +1021,7 @@ dialog_init (SolverState *state)
 		GNM_EE_SHEET_OPTIONAL, GNM_EE_MASK);
 	gtk_widget_set_hexpand (GTK_WIDGET (state->target_entry), TRUE);
 	gtk_grid_attach (grid, GTK_WIDGET (state->target_entry), 1, 0, 2, 1);
-	gnumeric_editable_enters (GTK_WINDOW (state->dialog),
+	gnm_editable_enters (GTK_WINDOW (state->dialog),
 				  GTK_WIDGET (state->target_entry));
 	gtk_widget_show (GTK_WIDGET (state->target_entry));
 	g_signal_connect_after (G_OBJECT (state->target_entry),	"changed",
@@ -1037,7 +1037,7 @@ dialog_init (SolverState *state)
 	gtk_widget_set_hexpand (GTK_WIDGET (state->change_cell_entry), TRUE);
 	gtk_grid_attach (grid,
 	                 GTK_WIDGET (state->change_cell_entry), 1, 2, 2, 1);
-	gnumeric_editable_enters (GTK_WINDOW (state->dialog),
+	gnm_editable_enters (GTK_WINDOW (state->dialog),
 				  GTK_WIDGET (state->change_cell_entry));
 	gtk_widget_show (GTK_WIDGET (state->change_cell_entry));
 	g_signal_connect_after (G_OBJECT (state->change_cell_entry), "changed",
@@ -1187,7 +1187,7 @@ dialog_init (SolverState *state)
 					       cell_name (target_cell));
 	else {
 		SheetView *sv = wb_control_cur_sheet_view
-			(WORKBOOK_CONTROL (state->wbcg));
+			(GNM_WBC (state->wbcg));
 		if (sv) {
 			GnmRange first = {sv->edit_pos, sv->edit_pos};
 			gnm_expr_entry_load_from_range (state->target_entry,
@@ -1251,7 +1251,7 @@ dialog_solver (WBCGtk *wbcg, Sheet *sheet)
 	int pass;
 
 	/* Only pop up one copy per workbook */
-	if (gnumeric_dialog_raise_if_exists (wbcg, SOLVER_KEY))
+	if (gnm_dialog_raise_if_exists (wbcg, SOLVER_KEY))
 		return;
 
 	/*
@@ -1294,7 +1294,7 @@ dialog_solver (WBCGtk *wbcg, Sheet *sheet)
 	gnm_dialog_setup_destroy_handlers (GTK_DIALOG (state->dialog), wbcg,
 					   GNM_DIALOG_DESTROY_SHEET_REMOVED);
 
-	gnumeric_keyed_dialog (state->wbcg, GTK_WINDOW (state->dialog),
+	gnm_keyed_dialog (state->wbcg, GTK_WINDOW (state->dialog),
 			       SOLVER_KEY);
 
 	gtk_widget_show (state->dialog);
