@@ -25,6 +25,7 @@
 #include "gnumeric.h"
 #include "gnm-so-line.h"
 #include "sheet-object-impl.h"
+#include "gutils.h"
 #include "xml-sax.h"
 
 #include <goffice/goffice.h>
@@ -88,7 +89,7 @@ typedef SheetObjectView		LineGocView;
 typedef SheetObjectViewClass	LineGocViewClass;
 static GSF_CLASS (LineGocView, so_line_goc_view,
 	so_line_goc_view_class_init, NULL,
-	SHEET_OBJECT_VIEW_TYPE)
+	GNM_SO_VIEW_TYPE)
 
 #endif /* GNM_WITH_GTK */
 enum {
@@ -118,9 +119,9 @@ sol_default_style (void)
 static void
 gnm_so_line_user_config (SheetObject *so, SheetControl *sc)
 {
-	dialog_so_styled (scg_wbcg (SHEET_CONTROL_GUI (sc)), G_OBJECT (so),
-			  GNM_SO_LINE (so)->style, sol_default_style (),
-			  _("Line/Arrow Properties"), SO_STYLED_STYLE_ONLY);
+	dialog_so_styled (scg_wbcg (GNM_SCG (sc)), G_OBJECT (so),
+			  sol_default_style (),
+			  _("Line/Arrow Properties"), SO_STYLED_LINE);
 }
 
 static void
@@ -155,43 +156,17 @@ gnm_so_line_new_view (SheetObject *so, SheetObjectViewContainer *container)
 #endif /* GNM_WITH_GTK */
 
 static void
-draw_arrow (GOArrow *arrow, cairo_t *cr,
+draw_arrow (const GOArrow *arrow, cairo_t *cr,
 	    double *x, double *y, double phi)
 {
-	switch (arrow->typ) {
-	case GO_ARROW_NONE:
-		return;
+	double dx, dy;
 
-	case GO_ARROW_KITE:
-		cairo_save (cr);
-		cairo_translate (cr, *x, *y);
-		cairo_rotate (cr, phi);
-		cairo_set_line_width (cr, 1.0);
-		cairo_new_path (cr);
-		cairo_move_to (cr, 0.0, 0.0);
-		cairo_line_to (cr, -arrow->c, -arrow->b);
-		cairo_line_to (cr, 0.0, -arrow->a);
-		cairo_line_to (cr, arrow->c, -arrow->b);
-		cairo_close_path (cr);
-		cairo_fill (cr);
-		cairo_restore (cr);
-
-		/* Make the line shorter so that the arrow won't be
-		 * on top of a (perhaps quite fat) line.  */
-		(*x) += arrow->a * sin (phi);
-		(*y) -= arrow->a * cos (phi);
-		break;
-
-	case GO_ARROW_OVAL:
-		cairo_save (cr);
-		cairo_translate (cr, *x, *y);
-		cairo_rotate (cr, phi);
-		cairo_scale (cr, arrow->a, arrow->b);
-		cairo_arc (cr, 0., 0., 1., 0., 2 * M_PI);
-		cairo_fill (cr);
-		cairo_restore (cr);
-		break;
-	}
+	cairo_save (cr);
+	cairo_translate (cr, *x, *y);
+	go_arrow_draw (arrow, cr, &dx, &dy, phi);
+	*x += dx;
+	*y += dy;
+	cairo_restore (cr);
 }
 
 static void
@@ -208,36 +183,20 @@ gnm_so_line_draw_cairo (SheetObject const *so, cairo_t *cr,
 	    style->line.dash_type == GO_LINE_NONE)
 		return;
 
-	switch (so->anchor.base.direction) {
-	case GOD_ANCHOR_DIR_UP_RIGHT:
-	case GOD_ANCHOR_DIR_DOWN_RIGHT:
+	if ((so->anchor.base.direction & GOD_ANCHOR_DIR_H_MASK) == GOD_ANCHOR_DIR_RIGHT) {
 		x1 = 0.;
 		x2 = width;
-		break;
-	case GOD_ANCHOR_DIR_UP_LEFT:
-	case GOD_ANCHOR_DIR_DOWN_LEFT:
+	} else {
 		x1 = width;
 		x2 = 0.;
-		break;
-	default:
-		g_warning ("Cannot guess direction!");
-		return;
 	}
 
-	switch (so->anchor.base.direction) {
-	case GOD_ANCHOR_DIR_UP_LEFT:
-	case GOD_ANCHOR_DIR_UP_RIGHT:
-		y1 = height;
-		y2 = 0.;
-		break;
-	case GOD_ANCHOR_DIR_DOWN_LEFT:
-	case GOD_ANCHOR_DIR_DOWN_RIGHT:
+	if ((so->anchor.base.direction & GOD_ANCHOR_DIR_V_MASK) == GOD_ANCHOR_DIR_DOWN) {
 		y1 = 0.;
 		y2 = height;
-		break;
-	default:
-		g_warning ("Cannot guess direction!");
-		return;
+	} else {
+		y1 = height;
+		y2 = 0.;
 	}
 
 	cairo_set_source_rgba (cr, GO_COLOR_TO_CAIRO (style->line.color));
@@ -346,8 +305,10 @@ gnm_so_line_prep_sax_parser (SheetObject *so, GsfXMLIn *xin,
 	double tmp, arrow_a = -1., arrow_b = -1., arrow_c = -1.;
 	int type = 0;
 
-	if (NULL == doc)
+	if (NULL == doc) {
 		doc = gsf_xml_in_doc_new (dtd, NULL);
+		gnm_xml_in_doc_dispose_on_exit (&doc);
+	}
 	gsf_xml_in_push_state (xin, doc, NULL, NULL, attrs);
 
 	go_arrow_clear (&sol->start_arrow);
@@ -448,7 +409,7 @@ gnm_so_line_finalize (GObject *object)
 static void
 gnm_so_line_class_init (GObjectClass *gobject_class)
 {
-	SheetObjectClass *so_class  = SHEET_OBJECT_CLASS (gobject_class);
+	SheetObjectClass *so_class  = GNM_SO_CLASS (gobject_class);
 
 	gnm_so_line_parent_class = g_type_class_peek_parent (gobject_class);
 
@@ -487,9 +448,9 @@ gnm_so_line_init (GObject *obj)
 	sol->style = sol_default_style ();
 	go_arrow_clear (&sol->start_arrow);
 	go_arrow_clear (&sol->end_arrow);
-	SHEET_OBJECT (obj)->anchor.base.direction = GOD_ANCHOR_DIR_NONE_MASK;
+	GNM_SO (obj)->anchor.base.direction = GOD_ANCHOR_DIR_NONE_MASK;
 }
 
 GSF_CLASS (GnmSOLine, gnm_so_line,
 	   gnm_so_line_class_init, gnm_so_line_init,
-	   SHEET_OBJECT_TYPE)
+	   GNM_SO_TYPE)
