@@ -428,9 +428,9 @@ cb_hide_unwanted_percentage (GnmCellIter const *iter,
 int
 gnm_filter_combo_index (GnmFilterCombo *fcombo)
 {
-	g_return_val_if_fail (IS_GNM_FILTER_COMBO (fcombo), 0);
+	g_return_val_if_fail (GNM_IS_FILTER_COMBO (fcombo), 0);
 
-	return (sheet_object_get_range (SHEET_OBJECT (fcombo))->start.col -
+	return (sheet_object_get_range (GNM_SO (fcombo))->start.col -
 		fcombo->filter->r.start.col);
 }
 
@@ -449,11 +449,11 @@ gnm_filter_combo_apply (GnmFilterCombo *fcombo, Sheet *target_sheet)
 	int col, start_row, end_row;
 	CellIterFlags iter_flags = CELL_ITER_IGNORE_HIDDEN;
 
-	g_return_if_fail (IS_GNM_FILTER_COMBO (fcombo));
+	g_return_if_fail (GNM_IS_FILTER_COMBO (fcombo));
 
 	filter = fcombo->filter;
 	cond = fcombo->cond;
-	col = sheet_object_get_range (SHEET_OBJECT (fcombo))->start.col;
+	col = sheet_object_get_range (GNM_SO (fcombo))->start.col;
 	start_row = filter->r.start.row + 1;
 	end_row = filter->r.end.row;
 
@@ -576,7 +576,7 @@ gnm_filter_combo_finalize (GObject *object)
 	gnm_filter_condition_free (fcombo->cond);
 	fcombo->cond = NULL;
 
-	parent = g_type_class_peek (SHEET_OBJECT_TYPE);
+	parent = g_type_class_peek (GNM_SO_TYPE);
 	parent->finalize (object);
 }
 
@@ -595,7 +595,7 @@ gnm_filter_combo_view_new (SheetObject *so, SheetObjectViewContainer *container)
 static void
 gnm_filter_combo_class_init (GObjectClass *gobject_class)
 {
-	SheetObjectClass *so_class = SHEET_OBJECT_CLASS (gobject_class);
+	SheetObjectClass *so_class = GNM_SO_CLASS (gobject_class);
 
 	/* Object class method overrides */
 	gobject_class->finalize = gnm_filter_combo_finalize;
@@ -617,7 +617,7 @@ gnm_filter_combo_class_init (GObjectClass *gobject_class)
 
 GSF_CLASS (GnmFilterCombo, gnm_filter_combo,
 	   gnm_filter_combo_class_init, gnm_filter_combo_init,
-	   SHEET_OBJECT_TYPE)
+	   GNM_SO_TYPE)
 
 /*************************************************************************/
 
@@ -636,8 +636,8 @@ gnm_filter_add_field (GnmFilter *filter, int i)
 	tmp.start.col = tmp.end.col = filter->r.start.col + i;
 	sheet_object_anchor_init (&anchor, &tmp, a_offsets,
 		GOD_ANCHOR_DIR_DOWN_RIGHT);
-	sheet_object_set_anchor (SHEET_OBJECT (fcombo), &anchor);
-	sheet_object_set_sheet (SHEET_OBJECT (fcombo), filter->sheet);
+	sheet_object_set_anchor (GNM_SO (fcombo), &anchor);
+	sheet_object_set_sheet (GNM_SO (fcombo), filter->sheet);
 
 	g_ptr_array_add (filter->fields, NULL);
 	for (n = filter->fields->len; --n > i ; )
