@@ -18,6 +18,7 @@
 #include "sheet-control-gui.h"
 #include "gui-file.h"
 #include "application.h"
+#include "gutils.h"
 #include "xml-sax.h"
 
 #include <goffice/goffice.h>
@@ -91,7 +92,7 @@ typedef SheetObjectView	SOImageGocView;
 typedef SheetObjectViewClass	SOImageGocViewClass;
 static GSF_CLASS (SOImageGocView, so_image_goc_view,
 	so_image_goc_view_class_init, NULL,
-	SHEET_OBJECT_VIEW_TYPE)
+	GNM_SO_VIEW_TYPE)
 
 /****************************************************************************/
 struct _SheetObjectImage {
@@ -100,9 +101,7 @@ struct _SheetObjectImage {
 	GOImage      *image;
 	char         *type;
 	char	     *name;
-	GByteArray   bytes;
 
-	gboolean dumped;
 	double   crop_top;
 	double   crop_bottom;
 	double   crop_left;
@@ -118,7 +117,7 @@ static SheetObjectClass *gnm_soi_parent_class;
 enum {
 	PROP_0,
 	PROP_IMAGE_TYPE,
-	PROP_IMAGE_DATA,
+	PROP_IMAGE,
 	PROP_PIXBUF
 };
 
@@ -130,7 +129,7 @@ enum {
  * @data_len
  * @copy_data:
  *
- * Assign raw data and type to @so assuming that it has not been initialized
+ * Assign raw data and type to @soi.
  * yet.
  **/
 void
@@ -140,15 +139,20 @@ sheet_object_image_set_image (SheetObjectImage *soi,
 			      unsigned      data_len,
 			      gboolean      copy_data)
 {
-	g_return_if_fail (IS_SHEET_OBJECT_IMAGE (soi));
-	g_return_if_fail (soi->bytes.data == NULL && soi->bytes.len == 0);
+	g_return_if_fail (GNM_IS_SO_IMAGE (soi));
 
-	soi->type       = (type && *type)? g_strdup (type): NULL;
-	soi->bytes.len  = data_len;
-	soi->bytes.data = copy_data ? g_memdup (data, data_len) : data;
-	soi->image = go_image_new_from_data (soi->type, soi->bytes.data, soi->bytes.len,
+	g_free (soi->type);
+	soi->type = (type && *type) ? g_strdup (type) : NULL;
+	if (soi->image)
+		g_object_unref (soi->image);
+	soi->image = go_image_new_from_data (soi->type, data, data_len,
 	                                     ((soi->type == NULL)? &soi->type: NULL), NULL);
+
+	if (!copy_data)
+		g_free (data);
+
 	if (soi->sheet_object.sheet != NULL) {
+		/* Share within document.  */
 		GOImage *image = go_doc_add_image (GO_DOC (soi->sheet_object.sheet->workbook), NULL, soi->image);
 		if (image != soi->image) {
 			g_object_unref (soi->image);
@@ -162,7 +166,7 @@ sheet_object_image_set_crop (SheetObjectImage *soi,
 			     double crop_left,  double crop_top,
 			     double crop_right, double crop_bottom)
 {
-	g_return_if_fail (IS_SHEET_OBJECT_IMAGE (soi));
+	g_return_if_fail (GNM_IS_SO_IMAGE (soi));
 
 	soi->crop_left   = crop_left;
 	soi->crop_top    = crop_top;
@@ -175,11 +179,9 @@ gnm_soi_finalize (GObject *object)
 {
 	SheetObjectImage *soi;
 
-	soi = SHEET_OBJECT_IMAGE (object);
-	g_free (soi->bytes.data);
+	soi = GNM_SO_IMAGE (object);
 	g_free (soi->type);
 	g_free (soi->name);
-	soi->bytes.data = NULL;
 	if (soi->image)
 		g_object_unref (soi->image);
 
@@ -189,7 +191,7 @@ gnm_soi_finalize (GObject *object)
 static SheetObjectView *
 gnm_soi_new_view (SheetObject *so, SheetObjectViewContainer *container)
 {
-	SheetObjectImage *soi = SHEET_OBJECT_IMAGE (so);
+	SheetObjectImage *soi = GNM_SO_IMAGE (so);
 	GocItem *item = NULL;
 
 	item = goc_item_new (
@@ -223,21 +225,6 @@ gnm_soi_new_view (SheetObject *so, SheetObjectViewContainer *container)
 	return gnm_pane_object_register (so, item, TRUE);
 }
 
-static gboolean
-soi_gdk_pixbuf_save (gchar const *buf,
-		     gsize count,
-		     GError **error,
-		     gpointer data)
-{
-	GsfOutput *output = GSF_OUTPUT (data);
-	gboolean ok = gsf_output_write (output, count, buf);
-
-	if (!ok && error)
-		*error = g_error_copy (gsf_output_error (output));
-
-	return ok;
-}
-
 static GOImageFormat const standard_formats[] = {
 	GO_IMAGE_FORMAT_PNG,
 	GO_IMAGE_FORMAT_JPG,
@@ -250,7 +237,7 @@ static GOImageFormat const standard_formats[] = {
 static GtkTargetList *
 gnm_soi_get_target_list (SheetObject const *so)
 {
-	SheetObjectImage *soi = SHEET_OBJECT_IMAGE (so);
+	SheetObjectImage *soi = GNM_SO_IMAGE (so);
 	GtkTargetList *tl = gtk_target_list_new (NULL, 0);
 	char *mime_str;
 	GSList *mimes, *ptr;
@@ -286,25 +273,16 @@ gnm_soi_write_image (SheetObject const *so, char const *format,
 		     G_GNUC_UNUSED double resolution,
 		     GsfOutput *output, GError **err)
 {
-	SheetObjectImage *soi = SHEET_OBJECT_IMAGE (so);
-	gboolean res = FALSE;
-	GdkPixbuf *pixbuf = go_image_get_pixbuf (soi->image);
+	SheetObjectImage *soi = GNM_SO_IMAGE (so);
+	gboolean res;
+	gsize length;
+	guint8 const *data;
+
+	g_return_if_fail (soi->image != NULL);
+
+	data = go_image_get_data (soi->image, &length);
+	res  = gsf_output_write (output, length, data);
 
-	if (!soi->type || strcmp (format, soi->type) == 0) {
-		if (soi->bytes.len == 0) {
-			gsize length;
-			guint8 const *data = go_image_get_data (soi->image, &length);
-			res = gsf_output_write (output,	length, data);
-		} else
-			res = gsf_output_write (output,
-						soi->bytes.len, soi->bytes.data);
-	} else if (pixbuf)
-		res = gdk_pixbuf_save_to_callback (pixbuf,
-						   soi_gdk_pixbuf_save, output,
-						   format,
-						   err, NULL);
-	if (pixbuf)
-		g_object_unref (pixbuf);
 	if (!res && err && *err == NULL)
 		*err = g_error_new (gsf_output_error_id (), 0,
 				   _("Unknown failure while saving image"));
@@ -321,7 +299,7 @@ soi_cb_save_as (SheetObject *so, SheetControl *sc)
 	GOImageFormatInfo const *format_info;
 	GdkPixbuf *pixbuf = NULL;
 	GError *err = NULL;
-	SheetObjectImage *soi = SHEET_OBJECT_IMAGE (so);
+	SheetObjectImage *soi = GNM_SO_IMAGE (so);
 
 	g_return_if_fail (soi != NULL);
 
@@ -334,7 +312,7 @@ soi_cb_save_as (SheetObject *so, SheetControl *sc)
 		l = g_slist_prepend (l, GUINT_TO_POINTER (sel_fmt));
 	}
 
-	wbcg = scg_wbcg (SHEET_CONTROL_GUI (sc));
+	wbcg = scg_wbcg (GNM_SCG (sc));
 
 	uri = go_gui_get_image_save_info (wbcg_toplevel (wbcg), l, &sel_fmt, NULL);
 	if (!uri)
@@ -371,7 +349,7 @@ static void
 content_start (GsfXMLIn *xin, xmlChar const **attrs)
 {
 	SheetObject *so = gnm_xml_in_cur_obj (xin);
-	SheetObjectImage *soi = SHEET_OBJECT_IMAGE (so);
+	SheetObjectImage *soi = GNM_SO_IMAGE (so);
 	char const *image_type = NULL, *image_name = NULL;
 
 	for (; attrs != NULL && attrs[0] && attrs[1] ; attrs += 2)
@@ -388,16 +366,15 @@ static void
 content_end (GsfXMLIn *xin, G_GNUC_UNUSED GsfXMLBlob *unknown)
 {
 	SheetObject *so = gnm_xml_in_cur_obj (xin);
-	SheetObjectImage *soi = SHEET_OBJECT_IMAGE (so);
+	SheetObjectImage *soi = GNM_SO_IMAGE (so);
 	GString *data = xin->content;
 
 	if (data->len >= 4) {
 		size_t len = gsf_base64_decode_simple (data->str, data->len);
-		soi->bytes.len = len;
-		soi->bytes.data = g_memdup (data->str, len);
-		soi->image = go_image_new_from_data (soi->type,
-						     soi->bytes.data,
-						     len, NULL, NULL);
+		if (soi->image)
+			g_object_unref (soi->image);
+		soi->image = go_image_new_from_data (soi->type, data->str, len,
+						     NULL, NULL);
 	}
 }
 
@@ -411,10 +388,12 @@ gnm_soi_prep_sax_parser (SheetObject *so, GsfXMLIn *xin,
 	  GSF_XML_IN_NODE_END
 	};
 	static GsfXMLInDoc *doc = NULL;
-	SheetObjectImage *soi = SHEET_OBJECT_IMAGE (so);
+	SheetObjectImage *soi = GNM_SO_IMAGE (so);
 
-	if (NULL == doc)
+	if (NULL == doc) {
 		doc = gsf_xml_in_doc_new (dtd, NULL);
+		gnm_xml_in_doc_dispose_on_exit (&doc);
+	}
 	gsf_xml_in_push_state (xin, doc, NULL, NULL, attrs);
 
 	for (; attrs != NULL && attrs[0] && attrs[1] ; attrs += 2) {
@@ -434,8 +413,8 @@ gnm_soi_write_xml_sax (SheetObject const *so, GsfXMLOut *output,
 {
 	SheetObjectImage *soi;
 
-	g_return_if_fail (IS_SHEET_OBJECT_IMAGE (so));
-	soi = SHEET_OBJECT_IMAGE (so);
+	g_return_if_fail (GNM_IS_SO_IMAGE (so));
+	soi = GNM_SO_IMAGE (so);
 
 	gsf_xml_out_add_float (output, "crop-top", soi->crop_top, 3);
 	gsf_xml_out_add_float (output, "crop-bottom", soi->crop_bottom, 3);
@@ -444,10 +423,13 @@ gnm_soi_write_xml_sax (SheetObject const *so, GsfXMLOut *output,
 	gsf_xml_out_start_element (output, "Content");
 	if (soi->type != NULL)
 		gsf_xml_out_add_cstr (output, "image-type", soi->type);
-	if (soi->image && go_image_get_name (soi->image)) {
-		gsf_xml_out_add_cstr (output, "name", go_image_get_name (soi->image));
-		if (sheet_object_get_sheet (so))
-			go_doc_save_image (GO_DOC (sheet_object_get_sheet (so)->workbook), go_image_get_name (soi->image));
+	if (soi->image) {
+		const char *name = go_image_get_name (soi->image);
+		Sheet *sheet = sheet_object_get_sheet (so);
+		if (name)
+			gsf_xml_out_add_cstr (output, "name", name);
+		if (sheet)
+			go_doc_save_image (GO_DOC (sheet->workbook), go_image_get_name (soi->image));
 		else {
 			/* looks that this may happen when pasting from another process, see #687414 */
 			gsize length;
@@ -456,8 +438,7 @@ gnm_soi_write_xml_sax (SheetObject const *so, GsfXMLOut *output,
 			gsf_xml_out_add_base64 (output, NULL, data, length);
 		}
 	} else {
-		gsf_xml_out_add_uint (output, "size-bytes", soi->bytes.len);
-		gsf_xml_out_add_base64 (output, NULL, soi->bytes.data, soi->bytes.len);
+		gsf_xml_out_add_uint (output, "size-bytes", 0);
 	}
 	gsf_xml_out_end_element (output);
 }
@@ -465,31 +446,26 @@ gnm_soi_write_xml_sax (SheetObject const *so, GsfXMLOut *output,
 static void
 gnm_soi_copy (SheetObject *dst, SheetObject const *src)
 {
-	SheetObjectImage const *soi = SHEET_OBJECT_IMAGE (src);
-	SheetObjectImage   *new_soi = SHEET_OBJECT_IMAGE (dst);
+	SheetObjectImage const *soi = GNM_SO_IMAGE (src);
+	SheetObjectImage   *new_soi = GNM_SO_IMAGE (dst);
 
 	new_soi->type		= g_strdup (soi->type);
-	new_soi->bytes.len	= soi->bytes.len;
-	new_soi->bytes.data	= g_memdup (soi->bytes.data, soi->bytes.len);
 	new_soi->crop_top	= soi->crop_top;
 	new_soi->crop_bottom	= soi->crop_bottom;
 	new_soi->crop_left	= soi->crop_left;
 	new_soi->crop_right	= soi->crop_right;
-	new_soi->image		= g_object_ref (soi->image);
+	new_soi->image		= soi->image ? g_object_ref (soi->image) : NULL;
 }
 
 static void
 gnm_soi_draw_cairo (SheetObject const *so, cairo_t *cr,
 		    double width, double height)
 {
-	GdkPixbuf *pixbuf;
-	GOImage *img;
-	int w, h;
-	SheetObjectImage *soi = SHEET_OBJECT_IMAGE (so);
+	SheetObjectImage *soi = GNM_SO_IMAGE (so);
 
 	if (soi->image) {
-		w = go_image_get_width (soi->image);
-		h = go_image_get_height (soi->image);
+		int w = go_image_get_width (soi->image);
+		int h = go_image_get_height (soi->image);
 		w -= soi->crop_left - soi->crop_right;
 		h -= soi->crop_top - soi->crop_bottom;
 		if (w <= 0 || h <= 0)
@@ -501,61 +477,25 @@ gnm_soi_draw_cairo (SheetObject const *so, cairo_t *cr,
 		cairo_translate (cr, -soi->crop_left, -soi->crop_top);
 		go_image_draw (soi->image, cr);
 		cairo_restore (cr);
-	} else {
-		pixbuf = go_image_get_pixbuf (soi->image);
-		if (!pixbuf || width == 0. || height == 0.)
-			return;
-		cairo_save (cr);
-		img = go_pixbuf_new_from_pixbuf (pixbuf);
-
-		w = gdk_pixbuf_get_width  (pixbuf);
-		h = gdk_pixbuf_get_height (pixbuf);
-		cairo_scale (cr, width / w, height / h);
-		go_image_draw (img, cr);
-		/*
-		 * We need to unset the source before we destroy the pattern.
-		 * cairo_restore will do that.  See #632439.
-		 */
-		cairo_restore (cr);
-		g_object_unref (img);
-		g_object_unref (pixbuf);
 	}
 }
 
 static void
 gnm_soi_default_size (SheetObject const *so, double *w, double *h)
 {
-	SheetObjectImage *soi = SHEET_OBJECT_IMAGE (so);
+	SheetObjectImage *soi = GNM_SO_IMAGE (so);
 	if (soi->image) {
 		*w = go_image_get_width (soi->image);
 		*h = go_image_get_height (soi->image);
 	} else {
-		GdkPixbuf *buf = go_image_get_pixbuf (soi->image);
-
-		if (!buf) {
-			*w = *h = 5;
-			return;
-		}
-
-		*w = gdk_pixbuf_get_width  (buf);
-		*h = gdk_pixbuf_get_height (buf);
-
-		/* In case buf is invalid with size 0,0 or if the image is just too
-		 * small to be useful default to something slightly larger
-		 * http://bugzilla.gnome.org/show_bug.cgi?id=462787
-		 **/
-		if ((*w * *h) < 25.) {
-			if (*w < 5) *w = 25;
-			if (*h < 5) *h = 25;
-		}
-		g_object_unref (buf);
+		*w = *h = 5;
 	}
 }
 
 static gboolean
 gnm_soi_assign_to_sheet (SheetObject *so, Sheet *sheet)
 {
-	SheetObjectImage *soi = SHEET_OBJECT_IMAGE (so);
+	SheetObjectImage *soi = GNM_SO_IMAGE (so);
 
 	if (soi->image/* && !go_image_get_name (soi->image)*/) {
 		GODoc *doc = GO_DOC (sheet->workbook);
@@ -567,11 +507,16 @@ gnm_soi_assign_to_sheet (SheetObject *so, Sheet *sheet)
 	} else if (soi->name) {
 		GODoc *doc = GO_DOC (sheet->workbook);
 		GType type = go_image_type_for_format (soi->type);
-		if (type != 0)
+		if (type != 0) {
 			soi->image = g_object_ref (go_doc_image_fetch (doc, soi->name, type));
+			if (GO_IS_PIXBUF (soi->image))
+				/* we need to ensure that the pixbuf type is set because it used to be missed, see #745297 */
+				g_object_set (soi->image, "image-type", soi->type, NULL);
+		}
 	} else {
 		/* There is nothing we can do */
 	}
+
 	return FALSE;
 }
 
@@ -581,19 +526,19 @@ gnm_soi_get_property (GObject     *object,
 		      GValue      *value,
 		      GParamSpec  *pspec)
 {
-	SheetObjectImage *soi = SHEET_OBJECT_IMAGE (object);
+	SheetObjectImage *soi = GNM_SO_IMAGE (object);
 	GdkPixbuf *pixbuf;
 
 	switch (property_id) {
 	case PROP_IMAGE_TYPE:
 		g_value_set_string (value, soi->type);
 		break;
-	case PROP_IMAGE_DATA:
-		g_value_set_pointer (value, &soi->bytes);
+	case PROP_IMAGE:
+		g_value_set_object (value, soi->image);
 		break;
 	case PROP_PIXBUF:
 		pixbuf = go_image_get_pixbuf (soi->image);
-		g_value_set_object (value, pixbuf);
+		g_value_take_object (value, pixbuf);
 		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -613,7 +558,7 @@ gnm_soi_class_init (GObjectClass *object_class)
 	object_class->get_property = gnm_soi_get_property;
 
 	/* SheetObject class method overrides */
-	so_class = SHEET_OBJECT_CLASS (object_class);
+	so_class = GNM_SO_CLASS (object_class);
 	so_class->new_view		= gnm_soi_new_view;
 	so_class->populate_menu		= gnm_soi_populate_menu;
 	so_class->write_xml_sax		= gnm_soi_write_xml_sax;
@@ -632,11 +577,12 @@ gnm_soi_class_init (GObjectClass *object_class)
 				      P_("Type of image"),
 				      NULL,
 				      GSF_PARAM_STATIC | G_PARAM_READABLE));
-	g_object_class_install_property (object_class, PROP_IMAGE_DATA,
-		 g_param_spec_pointer ("image-data",
-				       P_("Image data"),
-				       P_("Image data"),
-				       GSF_PARAM_STATIC | G_PARAM_READABLE));
+	g_object_class_install_property (object_class, PROP_IMAGE,
+		 g_param_spec_object ("image",
+				      P_("Image data"),
+				      P_("Image data"),
+				      GO_TYPE_IMAGE,
+				      GSF_PARAM_STATIC | G_PARAM_READABLE));
 	g_object_class_install_property (object_class, PROP_PIXBUF,
 		 g_param_spec_object ("pixbuf", "Pixbuf",
 				       "Pixbuf",
@@ -650,12 +596,11 @@ gnm_soi_init (GObject *obj)
 	SheetObjectImage *soi;
 	SheetObject *so;
 
-	soi = SHEET_OBJECT_IMAGE (obj);
-	soi->dumped = FALSE;
+	soi = GNM_SO_IMAGE (obj);
 	soi->crop_top = soi->crop_bottom = soi->crop_left = soi->crop_right
 		= 0.0;
 
-	so = SHEET_OBJECT (obj);
+	so = GNM_SO (obj);
 	so->anchor.base.direction = GOD_ANCHOR_DIR_DOWN_RIGHT;
 }
 
@@ -668,5 +613,5 @@ soi_imageable_init (SheetObjectImageableIface *soi_iface)
 
 GSF_CLASS_FULL (SheetObjectImage, sheet_object_image,
 	   NULL, NULL, gnm_soi_class_init, NULL,
-	   gnm_soi_init, SHEET_OBJECT_TYPE, 0,
-	   GSF_INTERFACE (soi_imageable_init, SHEET_OBJECT_IMAGEABLE_TYPE))
+	   gnm_soi_init, GNM_SO_TYPE, 0,
+	   GSF_INTERFACE (soi_imageable_init, GNM_SO_IMAGEABLE_TYPE))
