@@ -70,7 +70,7 @@ sheet_object_anchor_get_type (void)
 }
 
 /* Returns the class for a SheetObject */
-#define SO_CLASS(so) SHEET_OBJECT_CLASS(G_OBJECT_GET_CLASS(so))
+#define SO_CLASS(so) GNM_SO_CLASS(G_OBJECT_GET_CLASS(so))
 
 enum {
 	SO_PROP_0 = 0,
@@ -102,7 +102,7 @@ cb_so_size_position (SheetObject *so, SheetControl *sc)
 {
 	WBCGtk *wbcg;
 
-	g_return_if_fail (IS_SHEET_CONTROL_GUI (sc));
+	g_return_if_fail (GNM_IS_SCG (sc));
 
 	wbcg = scg_wbcg ((SheetControlGUI *)sc);
 
@@ -166,9 +166,9 @@ sheet_object_get_editor (SheetObject *so, SheetControl *sc)
 {
 	WBCGtk *wbcg;
 
-	g_return_if_fail (IS_SHEET_OBJECT (so));
+	g_return_if_fail (GNM_IS_SO (so));
 	g_return_if_fail (SO_CLASS (so));
-	g_return_if_fail (IS_SHEET_CONTROL_GUI (sc));
+	g_return_if_fail (GNM_IS_SCG (sc));
 
 	wbcg = scg_wbcg ((SheetControlGUI *)sc);
 
@@ -197,7 +197,7 @@ cb_so_copy (SheetObject *so, SheetControl *sc)
 gboolean
 sheet_object_can_print (SheetObject const *so)
 {
-	g_return_val_if_fail (IS_SHEET_OBJECT (so), FALSE);
+	g_return_val_if_fail (GNM_IS_SO (so), FALSE);
 	return  (so->flags & SHEET_OBJECT_IS_VISIBLE) &&
 		(so->flags & SHEET_OBJECT_PRINT) &&
 		SO_CLASS (so)->draw_cairo != NULL;
@@ -206,21 +206,21 @@ sheet_object_can_print (SheetObject const *so)
 gboolean
 sheet_object_can_resize (SheetObject const *so)
 {
-	g_return_val_if_fail (IS_SHEET_OBJECT (so), FALSE);
+	g_return_val_if_fail (GNM_IS_SO (so), FALSE);
 	return  so->flags & SHEET_OBJECT_CAN_RESIZE;
 }
 
 gboolean
 sheet_object_can_edit (SheetObject const *so)
 {
-	g_return_val_if_fail (IS_SHEET_OBJECT (so), FALSE);
+	g_return_val_if_fail (GNM_IS_SO (so), FALSE);
 	return  so->flags & SHEET_OBJECT_CAN_EDIT;
 }
 
 static gboolean
 sheet_object_can_prop (SheetObject const *so)
 {
-	g_return_val_if_fail (IS_SHEET_OBJECT (so), FALSE);
+	g_return_val_if_fail (GNM_IS_SO (so), FALSE);
 	return (sheet_object_can_edit (so) && (SO_CLASS(so)->user_config != NULL));
 }
 
@@ -273,7 +273,7 @@ sheet_object_populate_menu (SheetObject *so, GPtrArray *actions)
 {
 	g_return_if_fail  (NULL != so);
 
-	SHEET_OBJECT_CLASS (G_OBJECT_GET_CLASS(so))->populate_menu (so, actions);
+	GNM_SO_CLASS (G_OBJECT_GET_CLASS(so))->populate_menu (so, actions);
 }
 
 /**
@@ -289,7 +289,7 @@ sheet_objects_max_extent (Sheet *sheet)
 	GSList *ptr;
 
 	for (ptr = sheet->sheet_objects; ptr != NULL ; ptr = ptr->next ) {
-		SheetObject *so = SHEET_OBJECT (ptr->data);
+		SheetObject *so = GNM_SO (ptr->data);
 
 		if (max_pos.col < so->anchor.cell_bound.end.col)
 			max_pos.col = so->anchor.cell_bound.end.col;
@@ -320,7 +320,7 @@ static void
 sheet_object_get_property (GObject *obj, guint param_id,
 			   GValue  *value, GParamSpec *pspec)
 {
-	SheetObject *so = SHEET_OBJECT (obj);
+	SheetObject *so = GNM_SO (obj);
 
 	switch (param_id) {
 	case SO_PROP_NAME:
@@ -336,7 +336,7 @@ static void
 sheet_object_set_property (GObject *obj, guint param_id,
 			   GValue const *value, GParamSpec *pspec)
 {
-	SheetObject *so = SHEET_OBJECT (obj);
+	SheetObject *so = GNM_SO (obj);
 
 	switch (param_id) {
 	case SO_PROP_NAME:
@@ -352,7 +352,7 @@ sheet_object_set_property (GObject *obj, guint param_id,
 static void
 sheet_object_finalize (GObject *object)
 {
-	SheetObject *so = SHEET_OBJECT (object);
+	SheetObject *so = GNM_SO (object);
 	if (so->sheet != NULL)
 		sheet_object_clear_sheet (so);
 	g_free (so->name);
@@ -363,7 +363,7 @@ static void
 sheet_object_init (GObject *object)
 {
 	int i;
-	SheetObject *so = SHEET_OBJECT (object);
+	SheetObject *so = GNM_SO (object);
 
 	so->sheet = NULL;
 	so->flags = SHEET_OBJECT_IS_VISIBLE | SHEET_OBJECT_PRINT |
@@ -390,7 +390,7 @@ so_default_size (G_GNUC_UNUSED SheetObject const *so, double *width, double *hei
 static void
 sheet_object_class_init (GObjectClass *klass)
 {
-	SheetObjectClass *sheet_object_class = SHEET_OBJECT_CLASS (klass);
+	SheetObjectClass *sheet_object_class = GNM_SO_CLASS (klass);
 
 	parent_klass = g_type_class_peek_parent (klass);
 
@@ -412,14 +412,14 @@ sheet_object_class_init (GObjectClass *klass)
 				      GSF_PARAM_STATIC | G_PARAM_READWRITE));
 
 	signals [BOUNDS_CHANGED] = g_signal_new ("bounds-changed",
-		SHEET_OBJECT_TYPE,
+		GNM_SO_TYPE,
 		G_SIGNAL_RUN_LAST,
 		G_STRUCT_OFFSET (SheetObjectClass, bounds_changed),
 		NULL, NULL,
 		g_cclosure_marshal_VOID__VOID,
 		G_TYPE_NONE, 0);
 	signals [UNREALIZED] = g_signal_new ("unrealized",
-		SHEET_OBJECT_TYPE,
+		GNM_SO_TYPE,
 		G_SIGNAL_RUN_LAST,
 		G_STRUCT_OFFSET (SheetObjectClass, unrealized),
 		NULL, NULL,
@@ -443,10 +443,10 @@ sheet_object_get_view (SheetObject const *so, SheetObjectViewContainer *containe
 {
 	GList *l;
 
-	g_return_val_if_fail (IS_SHEET_OBJECT (so), NULL);
+	g_return_val_if_fail (GNM_IS_SO (so), NULL);
 
 	for (l = so->realized_list; l; l = l->next) {
-		SheetObjectView *view = SHEET_OBJECT_VIEW (l->data);
+		SheetObjectView *view = GNM_SO_VIEW (l->data);
 		if (container == g_object_get_qdata (G_OBJECT (view), sov_container_quark))
 			return view;
 	}
@@ -470,7 +470,7 @@ sheet_object_update_bounds (SheetObject *so, GnmCellPos const *pos)
 	gboolean is_hidden = TRUE;
 	int i, end;
 
-	g_return_if_fail (IS_SHEET_OBJECT (so));
+	g_return_if_fail (GNM_IS_SO (so));
 
 	if (pos != NULL &&
 	    so->anchor.cell_bound.end.col < pos->col &&
@@ -507,7 +507,7 @@ sheet_object_update_bounds (SheetObject *so, GnmCellPos const *pos)
 Sheet *
 sheet_object_get_sheet (SheetObject const *so)
 {
-	g_return_val_if_fail (IS_SHEET_OBJECT (so), NULL);
+	g_return_val_if_fail (GNM_IS_SO (so), NULL);
 
 	return so->sheet;
 }
@@ -533,7 +533,7 @@ cb_create_views (SheetObject *so)
 gboolean
 sheet_object_set_sheet (SheetObject *so, Sheet *sheet)
 {
-	g_return_val_if_fail (IS_SHEET_OBJECT (so), TRUE);
+	g_return_val_if_fail (GNM_IS_SO (so), TRUE);
 	g_return_val_if_fail (IS_SHEET (sheet), TRUE);
 
 	if (sheet == so->sheet)
@@ -575,7 +575,7 @@ sheet_object_clear_sheet (SheetObject *so)
 	GSList *ptr;
 	gpointer view_handler;
 
-	g_return_if_fail (IS_SHEET_OBJECT (so));
+	g_return_if_fail (GNM_IS_SO (so));
 
 	if (so->sheet == NULL) /* already removed */
 		return;
@@ -685,7 +685,7 @@ sheet_object_new_view (SheetObject *so, SheetObjectViewContainer *container)
 {
 	SheetObjectView *view;
 
-	g_return_val_if_fail (IS_SHEET_OBJECT (so), NULL);
+	g_return_val_if_fail (GNM_IS_SO (so), NULL);
 	g_return_val_if_fail (NULL != container, NULL);
 
 	view = sheet_object_get_view (so, container);
@@ -697,7 +697,7 @@ sheet_object_new_view (SheetObject *so, SheetObjectViewContainer *container)
 	if (NULL == view)
 		return NULL;
 
-	g_return_val_if_fail (IS_SHEET_OBJECT_VIEW (view), NULL);
+	g_return_val_if_fail (GNM_IS_SO_VIEW (view), NULL);
 
 	/* Store some useful information */
 	g_object_set_qdata (G_OBJECT (view), sov_so_quark, so);
@@ -775,7 +775,7 @@ sheet_object_draw_cairo_sized (SheetObject const *so, cairo_t *cr, double width,
 GnmRange const *
 sheet_object_get_range (SheetObject const *so)
 {
-	g_return_val_if_fail (IS_SHEET_OBJECT (so), NULL);
+	g_return_val_if_fail (GNM_IS_SO (so), NULL);
 
 	return &so->anchor.cell_bound;
 }
@@ -789,7 +789,7 @@ sheet_object_get_range (SheetObject const *so)
 SheetObjectAnchor const *
 sheet_object_get_anchor (SheetObject const *so)
 {
-	g_return_val_if_fail (IS_SHEET_OBJECT (so), NULL);
+	g_return_val_if_fail (GNM_IS_SO (so), NULL);
 
 	return &so->anchor;
 }
@@ -797,7 +797,7 @@ sheet_object_get_anchor (SheetObject const *so)
 void
 sheet_object_set_anchor (SheetObject *so, SheetObjectAnchor const *anchor)
 {
-	g_return_if_fail (IS_SHEET_OBJECT (so));
+	g_return_if_fail (GNM_IS_SO (so));
 
 	so->anchor = *anchor;
 	if (so->sheet != NULL) {
@@ -831,7 +831,7 @@ cell_offset_calc_pt (Sheet const *sheet, int i, gboolean is_col, double offset)
 void
 sheet_object_default_size (SheetObject *so, double *w, double *h)
 {
-	g_return_if_fail (IS_SHEET_OBJECT (so));
+	g_return_if_fail (GNM_IS_SO (so));
 	g_return_if_fail (w != NULL);
 	g_return_if_fail (h != NULL);
 
@@ -849,7 +849,7 @@ sheet_object_default_size (SheetObject *so, double *w, double *h)
 void
 sheet_object_position_pts_get (SheetObject const *so, double *coords)
 {
-	g_return_if_fail (IS_SHEET_OBJECT (so));
+	g_return_if_fail (GNM_IS_SO (so));
 	sheet_object_anchor_to_pts (&so->anchor, so->sheet, coords);
 }
 
@@ -950,7 +950,7 @@ sheet_objects_relocate (GnmExprRelocateInfo const *rinfo, gboolean update,
 	if (change_sheets) {
 		GSList *copy = g_slist_copy (rinfo->target_sheet->sheet_objects);
 		for (ptr = copy; ptr != NULL ; ptr = ptr->next ) {
-			SheetObject *so = SHEET_OBJECT (ptr->data);
+			SheetObject *so = GNM_SO (ptr->data);
 			GnmRange const *r  = &so->anchor.cell_bound;
 			if (range_contains (&dest, r->start.col, r->start.row)) {
 				clear_sheet (so, pundo);
@@ -961,7 +961,7 @@ sheet_objects_relocate (GnmExprRelocateInfo const *rinfo, gboolean update,
 
 	ptr = rinfo->origin_sheet->sheet_objects;
 	for (; ptr != NULL ; ptr = next ) {
-		SheetObject *so = SHEET_OBJECT (ptr->data);
+		SheetObject *so = GNM_SO (ptr->data);
 		GnmRange r = so->anchor.cell_bound;
 
 		next = ptr->next;
@@ -1019,7 +1019,7 @@ sheet_objects_get (Sheet const *sheet, GnmRange const *r, GType t)
 		GObject *obj = G_OBJECT (ptr->data);
 
 		if (t == G_TYPE_NONE || t == G_OBJECT_TYPE (obj)) {
-			SheetObject *so = SHEET_OBJECT (obj);
+			SheetObject *so = GNM_SO (obj);
 			if (r == NULL || range_contained (&so->anchor.cell_bound, r))
 				res = g_slist_prepend (res, so);
 		}
@@ -1047,7 +1047,7 @@ sheet_objects_clear (Sheet const *sheet, GnmRange const *r, GType t,
 		next = ptr->next;
 		if ((t == G_TYPE_NONE && G_OBJECT_TYPE (obj) != GNM_FILTER_COMBO_TYPE)
 		    || t == G_OBJECT_TYPE (obj)) {
-			SheetObject *so = SHEET_OBJECT (obj);
+			SheetObject *so = GNM_SO (obj);
 			if (r == NULL || range_contained (&so->anchor.cell_bound, r))
 				clear_sheet (so, pundo);
 		}
@@ -1276,8 +1276,8 @@ sheet_object_view_set_bounds (SheetObjectView *sov,
 {
 	SheetObjectViewClass *klass;
 
-	g_return_if_fail (IS_SHEET_OBJECT_VIEW (sov));
-	klass = SHEET_OBJECT_VIEW_GET_CLASS (sov);
+	g_return_if_fail (GNM_IS_SO_VIEW (sov));
+	klass = GNM_SO_VIEW_GET_CLASS (sov);
 	if (NULL != klass->set_bounds)
 		(klass->set_bounds) (sov, coords, visible);
 }
@@ -1299,7 +1299,7 @@ sheet_object_view_enter_notify (GocItem *item, double x, double y)
 {
 	SheetObject *so;
 
-	if (IS_GNM_PANE (item->canvas) && scg_wbcg (GNM_SIMPLE_CANVAS (item->canvas)->scg)->new_object) {
+	if (GNM_IS_PANE (item->canvas) && scg_wbcg (GNM_SIMPLE_CANVAS (item->canvas)->scg)->new_object) {
 		GnmItemGrid *grid = GNM_PANE (item->canvas)->grid;
 		return GOC_ITEM_GET_CLASS (grid)->enter_notify (GOC_ITEM (grid), x, y);
 	}
@@ -1316,13 +1316,13 @@ cb_so_menu_activate (GObject *menu, GocItem *view)
 	SheetObjectAction const *a = g_object_get_data (menu, "action");
 
 	if (a->func) {
-		SheetObject *so = sheet_object_view_get_so (SHEET_OBJECT_VIEW (view));
+		SheetObject *so = sheet_object_view_get_so (GNM_SO_VIEW (view));
 		gpointer data = g_object_get_data (G_OBJECT (view->canvas), "sheet-control");
 
 		if (data == NULL)
 			data = GNM_SIMPLE_CANVAS (view->canvas)->scg;
 
-		(a->func) (so, SHEET_CONTROL (data));
+		(a->func) (so, GNM_SC (data));
 	}
 }
 
@@ -1384,7 +1384,7 @@ sheet_object_view_button_pressed (GocItem *item, int button, double x, double y)
 {
 	GnmPane *pane;
 	SheetObject *so;
-	if (IS_GNM_PANE (item->canvas)) {
+	if (GNM_IS_PANE (item->canvas)) {
 		if (scg_wbcg (GNM_SIMPLE_CANVAS (item->canvas)->scg)->new_object) {
 			GnmItemGrid *grid = GNM_PANE (item->canvas)->grid;
 			return GOC_ITEM_GET_CLASS (grid)->button_pressed (GOC_ITEM (grid), button, x, y);
@@ -1401,7 +1401,7 @@ sheet_object_view_button_pressed (GocItem *item, int button, double x, double y)
 		/* cb_sheet_object_widget_canvas_event calls even if selected */
 		if (NULL == g_hash_table_lookup (pane->drag.ctrl_pts, so)) {
 			SheetObjectClass *soc =
-				G_TYPE_INSTANCE_GET_CLASS (so, SHEET_OBJECT_TYPE, SheetObjectClass);
+				G_TYPE_INSTANCE_GET_CLASS (so, GNM_SO_TYPE, SheetObjectClass);
 			GdkEventButton *event = (GdkEventButton *) goc_canvas_get_cur_event (item->canvas);
 
 			if (soc->interactive && button != 3)
@@ -1448,8 +1448,8 @@ sheet_object_view_button_pressed (GocItem *item, int button, double x, double y)
 static gboolean
 sheet_object_view_button2_pressed (GocItem *item, int button, double x, double y)
 {
-	if (button == 1 && !IS_GNM_PANE (item->canvas)) {
-		SheetControl *sc = SHEET_CONTROL (g_object_get_data (G_OBJECT (item->canvas), "sheet-control"));
+	if (button == 1 && !GNM_IS_PANE (item->canvas)) {
+		SheetControl *sc = GNM_SC (g_object_get_data (G_OBJECT (item->canvas), "sheet-control"));
 		SheetObject *so = (SheetObject *) g_object_get_qdata (G_OBJECT (item), sov_so_quark);
 
 		if (sc && sheet_object_can_edit (so))
@@ -1506,24 +1506,24 @@ sheet_object_imageable_get_type (void)
 	return type;
 }
 
-#define SHEET_OBJECT_IMAGEABLE_CLASS(o)	(G_TYPE_INSTANCE_GET_INTERFACE ((o), SHEET_OBJECT_IMAGEABLE_TYPE, SheetObjectImageableIface))
+#define GNM_SO_IMAGEABLE_CLASS(o)	(G_TYPE_INSTANCE_GET_INTERFACE ((o), GNM_SO_IMAGEABLE_TYPE, SheetObjectImageableIface))
 
 GtkTargetList *
 sheet_object_get_target_list (SheetObject const *so)
 {
-	if (!IS_SHEET_OBJECT_IMAGEABLE (so))
+	if (!GNM_IS_SO_IMAGEABLE (so))
 		return NULL;
 
-	return SHEET_OBJECT_IMAGEABLE_CLASS (so)->get_target_list (so);
+	return GNM_SO_IMAGEABLE_CLASS (so)->get_target_list (so);
 }
 
 void
 sheet_object_write_image (SheetObject const *so, char const *format, double resolution,
 			  GsfOutput *output, GError **err)
 {
-	g_return_if_fail (IS_SHEET_OBJECT_IMAGEABLE (so));
+	g_return_if_fail (GNM_IS_SO_IMAGEABLE (so));
 
-	SHEET_OBJECT_IMAGEABLE_CLASS (so)->write_image (so, format, resolution,
+	GNM_SO_IMAGEABLE_CLASS (so)->write_image (so, format, resolution,
 							output, err);
 
 }
@@ -1550,15 +1550,15 @@ sheet_object_exportable_get_type (void)
 	return type;
 }
 
-#define SHEET_OBJECT_EXPORTABLE_CLASS(o)	(G_TYPE_INSTANCE_GET_INTERFACE ((o), SHEET_OBJECT_EXPORTABLE_TYPE, SheetObjectExportableIface))
+#define GNM_SO_EXPORTABLE_CLASS(o)	(G_TYPE_INSTANCE_GET_INTERFACE ((o), GNM_SO_EXPORTABLE_TYPE, SheetObjectExportableIface))
 
 GtkTargetList *
 sheet_object_exportable_get_target_list (SheetObject const *so)
 {
-	if (!IS_SHEET_OBJECT_EXPORTABLE (so))
+	if (!GNM_IS_SO_EXPORTABLE (so))
 		return NULL;
 
-	return SHEET_OBJECT_EXPORTABLE_CLASS (so)->get_target_list (so);
+	return GNM_SO_EXPORTABLE_CLASS (so)->get_target_list (so);
 }
 
 void
@@ -1568,10 +1568,10 @@ sheet_object_write_object (SheetObject const *so, char const *format,
 {
 	GnmLocale *locale;
 
-	g_return_if_fail (IS_SHEET_OBJECT_EXPORTABLE (so));
+	g_return_if_fail (GNM_IS_SO_EXPORTABLE (so));
 
 	locale = gnm_push_C_locale ();
-	SHEET_OBJECT_EXPORTABLE_CLASS (so)->
+	GNM_SO_EXPORTABLE_CLASS (so)->
 		write_object (so, format, output, err, convs);
 	gnm_pop_C_locale (locale);
 }
@@ -1671,12 +1671,12 @@ sheet_objects_init (void)
 {
 	GNM_SO_LINE_TYPE;
 	GNM_SO_FILLED_TYPE;
-	SHEET_OBJECT_GRAPH_TYPE;
-	SHEET_OBJECT_IMAGE_TYPE;
+	GNM_SO_GRAPH_TYPE;
+	GNM_SO_IMAGE_TYPE;
 	GNM_GO_DATA_SCALAR_TYPE;
 	GNM_GO_DATA_VECTOR_TYPE;
 	GNM_GO_DATA_MATRIX_TYPE;
-	CELL_COMMENT_TYPE;
+	GNM_CELL_COMMENT_TYPE;
 
 	sheet_object_widget_register ();
 	sov_so_quark = g_quark_from_static_string ("SheetObject");
