@@ -114,7 +114,7 @@ gnm_validation_combo_view_new (SheetObject *so, SheetObjectViewContainer *contai
 static void
 gnm_validation_combo_class_init (GObjectClass *gobject_class)
 {
-	SheetObjectClass *so_class = SHEET_OBJECT_CLASS (gobject_class);
+	SheetObjectClass *so_class = GNM_SO_CLASS (gobject_class);
 	gobject_class->finalize	= gnm_validation_combo_finalize;
 	so_class->new_view = gnm_validation_combo_view_new;
 
@@ -136,7 +136,7 @@ gnm_validation_combo_new (GnmValidation const *val, SheetView *sv)
 
 	vcombo = g_object_new (GNM_VALIDATION_COMBO_TYPE, "sheet-view", sv, NULL);
 	gnm_validation_ref (vcombo->validation = val);
-	return SHEET_OBJECT (vcombo);
+	return GNM_SO (vcombo);
 }
 
 /***************************************************************************/
