@@ -289,7 +289,7 @@ xml_write_print_repeat_range (GnmOutputXML *state,
 
 static void
 xml_write_print_hf (GnmOutputXML *state, char const *name,
-		    PrintHF const *hf)
+		    GnmPrintHF const *hf)
 {
 	gsf_xml_out_start_element (state->output, name);
 	gsf_xml_out_add_cstr (state->output, "Left", hf->left_format);
@@ -326,7 +326,7 @@ xml_write_breaks (GnmOutputXML *state, GnmPageBreaks *breaks)
 }
 
 static void
-xml_write_print_info (GnmOutputXML *state, PrintInformation *pi)
+xml_write_print_info (GnmOutputXML *state, GnmPrintInformation *pi)
 {
 	char  *paper_name;
 	char const *uri;
@@ -1226,11 +1226,11 @@ xml_write_objects (GnmOutputXML *state, GSList *objects)
 	 */
 	for (ptr = objects ;ptr != NULL ; ptr = ptr->next) {
 		SheetObject *so = ptr->data;
-		SheetObjectClass *klass = SHEET_OBJECT_CLASS (G_OBJECT_GET_CLASS (so));
+		SheetObjectClass *klass = GNM_SO_CLASS (G_OBJECT_GET_CLASS (so));
 		if (klass == NULL || klass->write_xml_sax == NULL)
 			continue;
 
-		if (IS_CELL_COMMENT (so))
+		if (GNM_IS_CELL_COMMENT (so))
 			without_zorder = g_slist_prepend (without_zorder, so);
 		else
 			with_zorder = g_slist_prepend (with_zorder, so);
@@ -1240,7 +1240,7 @@ xml_write_objects (GnmOutputXML *state, GSList *objects)
 
 	for (ptr = objects ;ptr != NULL ; ptr = ptr->next) {
 		SheetObject *so = ptr->data;
-		SheetObjectClass *klass = SHEET_OBJECT_CLASS (G_OBJECT_GET_CLASS (so));
+		SheetObjectClass *klass = GNM_SO_CLASS (G_OBJECT_GET_CLASS (so));
 
 		if (needs_container) {
 			needs_container = FALSE;
@@ -1445,7 +1445,7 @@ gnm_xml_file_save_full (G_GNUC_UNUSED GOFileSaver const *fs,
 	GnmOutputXML state;
 	GsfOutput   *gzout = NULL;
 	GnmLocale   *locale;
-	WorkbookView *wb_view = WORKBOOK_VIEW (view);
+	WorkbookView *wb_view = GNM_WORKBOOK_VIEW (view);
 
 	if (compress) {
 		gzout  = gsf_output_gzip_new (output, NULL);
@@ -1465,7 +1465,12 @@ gnm_xml_file_save_full (G_GNUC_UNUSED GOFileSaver const *fs,
 
 	gsf_xml_out_start_element (state.output, GNM "Workbook");
 
-	/* backwards compat, must be first */
+	/*
+	 * As long as we want older versions of Gnumeric to be able to read
+	 * the files we produce, we should not increase the version number
+	 * in the file we write.  Until 1.12.21, v10 was the highest listed
+	 * xml-sax-read.c's content_ns.
+	 */
 	gsf_xml_out_add_cstr_unchecked (state.output, "xmlns:gnm",
 		"http://www.gnumeric.org/v10.dtd");
 #if 0 /* seems to break meta data */
